@@ -1,12 +1,12 @@
+from unit.utils.configuration import Configuration
 from unit.api.base_resource import BaseResource
 from unit.models.account_end_of_day import *
 from unit.models.codecs import DtoDecoder
 
 
 class AccountEndOfDayResource(BaseResource):
-    def __init__(self, api_url, token, retries):
-        super().__init__(api_url, token, retries)
-        self.resource = "account-end-of-day"
+    def __init__(self, configuration: Configuration):
+        super().__init__("account-end-of-day", configuration)
 
     def list(self, params: ListAccountEndOfDayParams = None) -> Union[UnitResponse[List[AccountEndOfDayDTO]], UnitError]:
         params = params or ListAccountEndOfDayParams()
