@@ -1,12 +1,12 @@
+from unit.utils.configuration import Configuration
 from unit.api.base_resource import BaseResource
 from unit.models.bill_pay import *
 from unit.models.codecs import DtoDecoder
 
 
 class BillPayResource(BaseResource):
-    def __init__(self, api_url, token, retries):
-        super().__init__(api_url, token, retries)
-        self.resource = "payments/billpay/billers"
+    def __init__(self, configuration: Configuration):
+        super().__init__("payments/billpay/billers", configuration)
 
     def get(self, params: GetBillersParams) -> Union[UnitResponse[List[BillerDTO]], UnitError]:
         parameters = {"name": params.name}
