@@ -1,12 +1,12 @@
+from unit.utils.configuration import Configuration
 from unit.api.base_resource import BaseResource
 from unit.models.statement import *
 from unit.models.codecs import DtoDecoder
 
 
 class StatementResource(BaseResource):
-    def __init__(self, api_url, token, retries):
-        super().__init__(api_url, token, retries)
-        self.resource = "statements"
+    def __init__(self, configuration: Configuration):
+        super().__init__("statements", configuration)
 
     def get(self, params: GetStatementParams) -> Union[UnitResponse[str], UnitError]:
         parameters = {"language": params.language}
